#!/usr/bin/env python3
# ----------------------------------------------------------------
# Programmer(s): Daniel R. Reynolds @ UMBC
# ----------------------------------------------------------------
# SUNDIALS Copyright Start
# Copyright (c) 2025-2026, Lawrence Livermore National Security,
# University of Maryland Baltimore County, and the SUNDIALS contributors.
# Copyright (c) 2013-2025, Lawrence Livermore National Security
# and Southern Methodist University.
# Copyright (c) 2002-2013, Lawrence Livermore National Security.
# All rights reserved.
#
# See the top-level LICENSE and NOTICE files for details.
#
# SPDX-License-Identifier: BSD-3-Clause
# SUNDIALS Copyright End
# ----------------------------------------------------------------
# matplotlib-based plotting script for ODE examples

# imports
import sys
import pylab as plt
import numpy as np

# load solution data file
data = np.loadtxt("solution.txt", dtype=np.double)

# determine number of time steps, number of fields
nt, nv = np.shape(data)

# extract time array
times = data[:, 0]

# parse comment line to determine solution names
f = open("solution.txt", "r")
commentline = f.readline()
commentsplit = commentline.split()
names = commentsplit[2:]

# create plot
plt.figure()

# add curves to figure
for i in range(nv - 1):
    plt.plot(times, data[:, i + 1], label=names[i])
plt.xlabel("t")
if nv > 2:
    plt.ylabel("solutions")
else:
    plt.ylabel("solution")
plt.legend(loc="upper right", shadow=True)
plt.grid()
plt.savefig("solution.png")


##### end of script #####



#!/usr/bin/env python3
# ----------------------------------------------------------------
# Programmer(s): Daniel R. Reynolds @ UMBC
# ----------------------------------------------------------------
# SUNDIALS Copyright Start
# Copyright (c) 2025-2026, Lawrence Livermore National Security,
# University of Maryland Baltimore County, and the SUNDIALS contributors.
# Copyright (c) 2013-2025, Lawrence Livermore National Security
# and Southern Methodist University.
# Copyright (c) 2002-2013, Lawrence Livermore National Security.
# All rights reserved.
#
# See the top-level LICENSE and NOTICE files for details.
#
# SPDX-License-Identifier: BSD-3-Clause
# SUNDIALS Copyright End
# ----------------------------------------------------------------
# matplotlib-based plotting script
# ----------------------------------------------------------------

# imports
import glob
import sys
import pylab as plt
import numpy as np

# load mesh data file
mesh = np.loadtxt("mesh.txt", dtype=np.double)

# load output time file
times = np.loadtxt("t.000000.txt", dtype=np.double)

# load solution data files
ufiles = glob.glob("u." + ("[0-9]" * 6) + ".txt")
ufiles.sort()
vfiles = glob.glob("v." + ("[0-9]" * 6) + ".txt")
vfiles.sort()
wfiles = glob.glob("w." + ("[0-9]" * 6) + ".txt")
wfiles.sort()
udata = np.loadtxt(ufiles[0], dtype=np.double)
vdata = np.loadtxt(vfiles[0], dtype=np.double)
wdata = np.loadtxt(wfiles[0], dtype=np.double)
for idx in range(1, len(ufiles)):
    udata = np.hstack((udata, np.loadtxt(ufiles[idx], dtype=np.double)))
    vdata = np.hstack((vdata, np.loadtxt(vfiles[idx], dtype=np.double)))
    wdata = np.hstack((wdata, np.loadtxt(wfiles[idx], dtype=np.double)))

# determine number of time steps, mesh size
nt, nx = np.shape(udata)

# determine min/max values
umin = 0.9 * udata.min()
umax = 1.1 * udata.max()
vmin = 0.9 * vdata.min()
vmax = 1.1 * vdata.max()
wmin = 0.9 * wdata.min()
wmax = 1.1 * wdata.max()
xmax = mesh.max()
minval = np.array([umin, vmin, wmin]).min()
maxval = np.array([umax, vmax, wmax]).max()

# generate plots of results
for tstep in range(nt):

    # set string constants for output plots, current time, mesh size
    pname = "solution." + repr(tstep).zfill(3) + ".png"
    tstr = repr(tstep)
    nxstr = repr(nx)

    # plot current solution and save to disk
    plt.figure(1)
    plt.plot(mesh, udata[tstep, :], label="u")
    plt.plot(mesh, vdata[tstep, :], label="v")
    plt.plot(mesh, wdata[tstep, :], label="w")
    plt.xlabel("x")
    plt.ylabel("solution")
    plt.title("Solutions at output " + tstr + ", mesh = " + nxstr)
    plt.axis((0.0, xmax, minval, maxval))
    plt.grid()
    plt.legend(loc="upper right", shadow=True)
    plt.savefig(pname)
    plt.close()

# set string constants for output plots, current time, mesh size
pname = "solution_at_x0.png"
xstr = repr(mesh[0])

# plot current solution and save to disk
plt.figure(1)
plt.plot(times, udata[:, 0], label="u")
plt.plot(times, vdata[:, 0], label="v")
plt.plot(times, wdata[:, 0], label="w")
plt.xlabel("t")
plt.ylabel("solution")
plt.title("Solutions at output at x = " + xstr)
plt.axis((times[0], times[-1], minval, maxval))
plt.grid()
plt.legend(loc="upper right", shadow=True)
plt.savefig(pname)
plt.close()


##### end of script #####



#!/usr/bin/env python3
# ----------------------------------------------------------------
# Programmer(s): Cody J. Balos @ LLNL
# ----------------------------------------------------------------
# SUNDIALS Copyright Start
# Copyright (c) 2025-2026, Lawrence Livermore National Security,
# University of Maryland Baltimore County, and the SUNDIALS contributors.
# Copyright (c) 2013-2025, Lawrence Livermore National Security
# and Southern Methodist University.
# Copyright (c) 2002-2013, Lawrence Livermore National Security.
# All rights reserved.
#
# See the top-level LICENSE and NOTICE files for details.
#
# SPDX-License-Identifier: BSD-3-Clause
# SUNDIALS Copyright End
# ----------------------------------------------------------------
# matplotlib-based plotting script for ark_kepler.c
# ----------------------------------------------------------------

import numpy as np
import matplotlib.pyplot as plt
import argparse

parser = argparse.ArgumentParser(
    description="Script for plotting the energy, angular momentum, and phase space solution for ark_kepler.c"
)
parser.add_argument("output_times", help="file with the output times")
parser.add_argument("solution", help="file with the solution")
parser.add_argument("conserved_quantities", help="file with conserved quantities")

args = parser.parse_args()

t = np.loadtxt(args.output_times, dtype=np.float64)
y = np.loadtxt(args.solution, dtype=np.float64)
y = np.reshape(y, (y.shape[0] // 4, 4))

plt.figure(dpi=200)
plt.plot(y[:, 0], y[:, 1])
plt.savefig("ark_kepler_phase.png")
plt.close()

conserved = np.loadtxt(args.conserved_quantities, delimiter=",", dtype=np.float64)
energy = conserved[:, 0]
energy_0 = conserved[0, 0]
L = conserved[:, 1]
L_0 = conserved[0, 1]

plt.figure(dpi=200)
plt.title("Energy")
plt.plot(t, np.abs(energy))
plt.ylabel("H(t,p,q)")
plt.xlabel("<---  t  --->")
plt.xscale("log")
plt.savefig("ark_kepler_energy.png")
plt.close()

plt.figure(dpi=200)
plt.title("Momentum")
plt.plot(t, L)
plt.ylabel("L(t,p,q)")
plt.xlabel("<---  t  --->")
plt.xscale("log")
plt.savefig("ark_kepler_momentum.png")
plt.close()

#
#  Time plot.
#
plt.figure(dpi=200)
plt.plot(t, y[:, 0], linewidth=2)
plt.plot(t, y[:, 1], linewidth=2)
plt.plot(t, y[:, 2], linewidth=2)
plt.plot(t, y[:, 3], linewidth=2)
plt.grid(True)
plt.legend(["P", "P'", "Q", "Q'"])
plt.xlabel("<---  t  --->")
plt.ylabel("<---  y(1:4)  --->")
plt.title("Solution in Time")
plt.savefig("ark_kepler_plot.png")
plt.close()

#
#  Phase plot.
#
plt.figure(dpi=200)
plt.plot(y[:, 0], y[:, 1], linewidth=0.1)
plt.grid(True)
plt.xlabel("<---  y1  --->")
plt.ylabel("<---  y2  --->")
plt.title("Phase Plot")
plt.savefig("ark_kepler_phase.png")
plt.close()
